rLSaddQCterms: Add quadratic elements to the given model.
Description
R interface function for LINDO API function LSaddQCterms. For more information,
please refer to LINDO API User Manual.
Usage
rLSaddQCterms(model,nQCnonzeros,paiQCconndx,paiQCvarndx1,paiQCvarndx2,padQCcoef)
Arguments
nQCnonzeros
Total number of nonzeros in quadratic coefficient matrices to be added.
paiQCconndx
An integer array containing the index of the constraint associated with each nonzero quadratic term.
paiQCvarndx1
An integer array containing the first variable defining each quadratic term.
paiQCvarndx2
An integer array containing the second variable defining each quadratic term.
padQCcoef
A double array containing the nonzero coefficients in the quadratic matrix.
Value
An R list object with components:
- ErrorCode
- Zero if successful, nonzero otherwise.
References
LINDO SYSTEMS home page at www.lindo.com